package com.xinda.itsm.mapper;

import java.util.List;
import com.xinda.itsm.domain.ExampleReport;

/**
 * 例报管理Mapper接口
 *
 * @author kerwincui
 * @date 2025-04-23
 */
public interface ExampleReportMapper
{
    /**
     * 查询例报管理
     *
     * @param exampleReportId 例报管理主键
     * @return 例报管理
     */
    public ExampleReport selectExampleReportByExampleReportId(Long exampleReportId);

    /**
     * 查询例报管理列表
     *
     * @param exampleReport 例报管理
     * @return 例报管理集合
     */
    public List<ExampleReport> selectExampleReportList(ExampleReport exampleReport);

    /**
     * 新增例报管理
     *
     * @param exampleReport 例报管理
     * @return 结果
     */
    public int insertExampleReport(ExampleReport exampleReport);

    /**
     * 修改例报管理
     *
     * @param exampleReport 例报管理
     * @return 结果
     */
    public int updateExampleReport(ExampleReport exampleReport);

    /**
     * 删除例报管理
     *
     * @param exampleReportId 例报管理主键
     * @return 结果
     */
    public int deleteExampleReportByExampleReportId(Long exampleReportId);

    /**
     * 批量删除例报管理
     *
     * @param exampleReportIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteExampleReportByExampleReportIds(Long[] exampleReportIds);
}
